==> kimageannotator_0.6.0.orig.tar.gz: kImageAnnotator-0.6.0/translations/kImageAnnotator_si.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="si">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select This</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>පිටපත්</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>අලවන්න</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>සංස්කරණය</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>වර්ණය</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Width</source>
        <translation>පළල</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>වසන්න</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>අනෙක්වා වසන්න</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>සියල්ල වසන්න</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation>මෙවලම් තේරීම</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>සබල කර ඇත</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>අබල කර ඇත</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>අවලංගු</translation>
    </message>
    <message>
        <source>X:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Y:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>W:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>H:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>යොදන්න</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Underline</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Border</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Y:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>W:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>H:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>යොදන්න</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>අවලංගු</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>වර්ණය:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation>හරි</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>අවලංගු</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flip</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>පළල:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>උස:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>හරි</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>අවලංගු</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Percent</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>තෝරන්න</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number</source>
        <translation>අංකය</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>ඊතලය</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>ද්විත්ව ඊතලය</translation>
    </message>
    <message>
        <source>Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blur</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>අංක ඊතලය</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>අනුපිටපත</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation>විශාලනය (% 1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation>කුඩාලනය (% 1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> kimageannotator_0.7.2.orig.tar.gz: kImageAnnotator-0.7.2/translations/kImageAnnotator_si.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="si">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select This</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>පිටපත්</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>අලවන්න</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>සංස්කරණය</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationControlsWidget</name>
    <message>
        <source>Controls</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>වර්ණය</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Width</source>
        <translation>පළල</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>වසන්න</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>අනෙක්වා වසන්න</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>සියල්ල වසන්න</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation>මෙවලම් තේරීම</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>සබල කර ඇත</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>අබල කර ඇත</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::Controls</name>
    <message>
        <source>Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Redo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Crop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify canvas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>අවලංගු</translation>
    </message>
    <message>
        <source>X:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Y:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>W:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>H:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>යොදන්න</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CutWidget</name>
    <message>
        <source>Vertical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished">යොදන්න</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">අවලංගු</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Underline</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Border</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Y:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>W:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>H:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>යොදන්න</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>අවලංගු</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>වර්ණය:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation>හරි</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>අවලංගු</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flip</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>පළල:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>උස:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>හරි</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>අවලංගු</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Percent</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>තෝරන්න</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number</source>
        <translation>අංකය</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>ඊතලය</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>ද්විත්ව ඊතලය</translation>
    </message>
    <message>
        <source>Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blur</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>අංක ඊතලය</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>අනුපිටපත</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation>විශාලනය (% 1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation>කුඩාලනය (% 1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset Zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit image to view (%1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
